@@ -1,8 +1,8 @@
 #
-# $Id: Libdnet.pm,v c57765ed0538 2024/10/28 15:05:03 gomor $
+# $Id: Libdnet.pm 13 2008-11-25 21:36:12Z gomor $
 #
 # Copyright (c) 2004 Vlad Manilici
-# Copyright (c) 2008-2024 Patrice <GomoR> Auffret
+# Copyright (c) 2008 Patrice <GomoR> Auffret
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -31,9 +31,11 @@
 package Net::Libdnet;
 use strict; use warnings;
 
-use base qw(Exporter DynaLoader);
+our $VERSION = '0.90';
 
-our $VERSION = '0.99.1';
+use Exporter;
+use DynaLoader;
+our @ISA = qw(Exporter DynaLoader);
 
 our %EXPORT_TAGS = (
    obsolete => [qw(
@@ -104,24 +106,24 @@ our %EXPORT_TAGS = (
       dnet_ip_close
    )],
    consts => [qw(
-      DNET_ADDR_TYPE_NONE
-      DNET_ADDR_TYPE_ETH
-      DNET_ADDR_TYPE_IP
-      DNET_ADDR_TYPE_IP6
-      DNET_FW_OP_ALLOW
-      DNET_FW_OP_BLOCK
-      DNET_FW_DIR_IN
-      DNET_FW_DIR_OUT
-      DNET_INTF_TYPE_OTHER
-      DNET_INTF_TYPE_ETH
-      DNET_INTF_TYPE_LOOPBACK
-      DNET_INTF_TYPE_TUN
-      DNET_INTF_FLAG_UP
-      DNET_INTF_FLAG_LOOPBACK
-      DNET_INTF_FLAG_POINTOPOINT
-      DNET_INTF_FLAG_NOARP
-      DNET_INTF_FLAG_BROADCAST
-      DNET_INTF_FLAG_MULTICAST
+      ADDR_TYPE_NONE
+      ADDR_TYPE_ETH
+      ADDR_TYPE_IP
+      ADDR_TYPE_IP6
+      FW_OP_ALLOW
+      FW_OP_BLOCK
+      FW_DIR_IN
+      FW_DIR_OUT
+      INTF_TYPE_OTHER
+      INTF_TYPE_ETH
+      INTF_TYPE_LOOPBACK
+      INTF_TYPE_TUN
+      INTF_FLAG_UP
+      INTF_FLAG_LOOPBACK
+      INTF_FLAG_POINTOPOINT
+      INTF_FLAG_NOARP
+      INTF_FLAG_BROADCAST
+      INTF_FLAG_MULTICAST
    )],
 );
 our @EXPORT = (
@@ -138,39 +140,39 @@ our @EXPORT = (
 
 __PACKAGE__->bootstrap($VERSION);
 
-use constant DNET_ADDR_TYPE_NONE => 0;
-use constant DNET_ADDR_TYPE_ETH  => 1;
-use constant DNET_ADDR_TYPE_IP   => 2;
-use constant DNET_ADDR_TYPE_IP6  => 3;
+use constant ADDR_TYPE_NONE => 0;
+use constant ADDR_TYPE_ETH  => 1;
+use constant ADDR_TYPE_IP   => 2;
+use constant ADDR_TYPE_IP6  => 3;
 
-use constant DNET_FW_OP_ALLOW => 1;
-use constant DNET_FW_OP_BLOCK => 2;
-use constant DNET_FW_DIR_IN   => 1;
-use constant DNET_FW_DIR_OUT  => 2;
+use constant FW_OP_ALLOW => 1;
+use constant FW_OP_BLOCK => 2;
+use constant FW_DIR_IN   => 1;
+use constant FW_DIR_OUT  => 2;
 
-use constant DNET_INTF_TYPE_OTHER       => 1;
-use constant DNET_INTF_TYPE_ETH         => 6;
-use constant DNET_INTF_TYPE_LOOPBACK    => 24;
-use constant DNET_INTF_TYPE_TUN         => 53;
-use constant DNET_INTF_FLAG_UP          => 0x01;
-use constant DNET_INTF_FLAG_LOOPBACK    => 0x02;
-use constant DNET_INTF_FLAG_POINTOPOINT => 0x04;
-use constant DNET_INTF_FLAG_NOARP       => 0x08;
-use constant DNET_INTF_FLAG_BROADCAST   => 0x10;
-use constant DNET_INTF_FLAG_MULTICAST   => 0x20;
+use constant INTF_TYPE_OTHER       => 1;
+use constant INTF_TYPE_ETH         => 6;
+use constant INTF_TYPE_LOOPBACK    => 24;
+use constant INTF_TYPE_TUN         => 53;
+use constant INTF_FLAG_UP          => 0x01;
+use constant INTF_FLAG_LOOPBACK    => 0x02;
+use constant INTF_FLAG_POINTOPOINT => 0x04;
+use constant INTF_FLAG_NOARP       => 0x08;
+use constant INTF_FLAG_BROADCAST   => 0x10;
+use constant INTF_FLAG_MULTICAST   => 0x20;
 
-sub addr_cmp     { _obsolete_addr_cmp    (@_) }
-sub addr_bcast   { _obsolete_addr_bcast  (@_) }
-sub addr_net     { _obsolete_addr_net    (@_) }
-sub arp_add      { _obsolete_arp_add     (@_) }
-sub arp_delete   { _obsolete_arp_delete  (@_) }
-sub arp_get      { _obsolete_arp_get     (@_) }
-sub intf_get     { _obsolete_intf_get    (@_) }
-sub intf_get_src { _obsolete_intf_get_src(@_) }
-sub intf_get_dst { _obsolete_intf_get_dst(@_) }
-sub route_add    { _obsolete_route_add   (@_) }
-sub route_delete { _obsolete_route_delete(@_) }
-sub route_get    { _obsolete_route_get   (@_) }
+sub addr_cmp     { obsolete_addr_cmp    (@_) }
+sub addr_bcast   { obsolete_addr_bcast  (@_) }
+sub addr_net     { obsolete_addr_net    (@_) }
+sub arp_add      { obsolete_arp_add     (@_) }
+sub arp_delete   { obsolete_arp_delete  (@_) }
+sub arp_get      { obsolete_arp_get     (@_) }
+sub intf_get     { obsolete_intf_get    (@_) }
+sub intf_get_src { obsolete_intf_get_src(@_) }
+sub intf_get_dst { obsolete_intf_get_dst(@_) }
+sub route_add    { obsolete_route_add   (@_) }
+sub route_delete { obsolete_route_delete(@_) }
+sub route_get    { obsolete_route_get   (@_) }
 
 1;
 
@@ -333,7 +335,7 @@ Net::Libdnet provides a simplified, portable interface to several low-level netw
 
 All the original and obsolete functions return I<undef> and print a warning message to the standard error when a problem occurs. The obsolete functions are: B<addr_cmp>, B<addr_bcast>, B<addr_net>, B<arp_add>, B<arp_delete>, B<arp_get>, B<intf_get>, B<intf_get_src>, B<intf_get_dst>, B<route_add>, B<route_delete>, B<route_get>.
 
-These obsolete functions will continue to work, to keep backward compatibility, but should not be used anymore. The new APIs should be preferred. There are two new APIs, one is the low-level one, matching libdnet functions, and the other one is a high-level API, matching a more Perl object oriented programming. This latest one is highly preferred.
+These osbsolete functions will continue to work, to keep backward compatibility, but should not be used anymore. The new APIs should be prefered. There are two new APIs, one is the low-level one, matching libdnet functions, and the other one is a high-level API, matching a more Perl object oriented programming. This latest one is highly prefered.
 
 Net::Libdnet module implements the low-level API. The high-level API is accessible by using the following modules: B<Net::Libdnet::Intf>, B<Net::Libdnet::Route>, B<Net::Libdnet::Fw>, B<Net::Libdnet::Arp>, B<Net::Libdnet::Eth>, B<Net::Libdnet::Ip> and B<Net::Libdnet::Tun>.
 
@@ -411,7 +413,8 @@ Takes an intf handle, and an IP address as parameters. Returns a hash in dnet fo
 
 =item B<dnet_intf_set> (scalar, scalar)
 
-Takes an intf handle, and a hash ref in dnet format as parameters. Returns 1 on success, undef on error.
+Takes an intf handle, and a hash ref in dnet format as parameters. Returns 1 on success,
+ undef on error.
 
 =item B<dnet_intf_loop> (scalar, subref, scalarref)
 
@@ -583,45 +586,75 @@ They should not be used anymore. You have been warned.
 
 =back
 
+These ones are used internally only.
+
+=over 4
+
+=item B<obsolete_addr_bcast>
+
+=item B<obsolete_addr_cmp>
+
+=item B<obsolete_addr_net>
+
+=item B<obsolete_arp_add>
+
+=item B<obsolete_arp_delete>
+
+=item B<obsolete_arp_get>
+
+=item B<obsolete_intf_get>
+
+=item B<obsolete_intf_get_dst>
+
+=item B<obsolete_intf_get_src>
+
+=item B<obsolete_route_add>
+
+=item B<obsolete_route_delete>
+
+=item B<obsolete_route_get>
+
+=back
+
 =head1 CONSTANTS
 
 =over 4
 
-=item B<DNET_ADDR_TYPE_NONE>
+=item B<ADDR_TYPE_NONE>
 
-=item B<DNET_ADDR_TYPE_ETH>
+=item B<ADDR_TYPE_ETH>
 
-=item B<DNET_ADDR_TYPE_IP>
+=item B<ADDR_TYPE_IP>
 
-=item B<DNET_ADDR_TYPE_IP6>
+=item B<ADDR_TYPE_IP6>
 
-=item B<DNET_FW_OP_ALLOW>
+=item B<FW_OP_ALLOW>
 
-=item B<DNET_FW_OP_BLOCK>
+=item B<FW_OP_BLOCK>
 
-=item B<DNET_FW_DIR_IN>
+=item B<FW_DIR_IN>
 
-=item B<DNET_FW_DIR_OUT>
+=item B<FW_DIR_OUT>
 
-=item B<DNET_INTF_TYPE_OTHER>
+=item B<INTF_TYPE_OTHER>
 
-=item B<DNET_INTF_TYPE_ETH>
+=item B<INTF_TYPE_ETH>
 
-=item B<DNET_INTF_TYPE_LOOPBACK>
+=item B<INTF_TYPE_LOOPBACK>
 
-=item B<DNET_INTF_TYPE_TUN>
+=item B<INTF_TYPE_TUN>
 
-=item B<DNET_INTF_FLAG_UP>
+=item B<INTF_FLAG_UP>
 
-=item B<DNET_INTF_FLAG_LOOPBACK>
+=item B<INTF_FLAG_LOOPBACK>
 
-=item B<DNET_INTF_FLAG_POINTOPOINT>
+=item B<INTF_FLAG_POINTOPOINT>
 
-=item B<DNET_INTF_FLAG_NOARP>
+=item B<INTF_FLAG_NOARP>
 
-=item B<DNET_INTF_FLAG_BROADCAST>
+=item B<INTF_FLAG_BROADCAST>
 
-=item B<DNET_INTF_FLAG_MULTICAST>
+=item B<INTF_FLAG_MULTICAST>
 
 =back
 
@@ -631,7 +664,7 @@ You may distribute this module under the terms of the BSD license. See LICENSE f
 
 Copyright (c) 2004, Vlad Manilici
 
-Copyright (c) 2008-2024, Patrice <GomoR> Auffret
+Copyright (c) 2008, Patrice <GomoR> Auffret
 
 =head1 SEE ALSO
 
