@@ -1,11 +1,11 @@
 #
-# $Id: Eth.pm,v c57765ed0538 2024/10/28 15:05:03 gomor $
+# $Id: Eth.pm 13 2008-11-25 21:36:12Z gomor $
 #
 package Net::Libdnet::Eth;
 use strict; use warnings;
 
-use base qw(Class::Gomor::Array);
-
+require Class::Gomor::Array;
+our @ISA = qw(Class::Gomor::Array);
 our @AS  = qw(
    device
    _handle
@@ -56,7 +56,11 @@ Net::Libdnet::Eth - high level API to access libdnet eth_* functions
 
    use Net::Libdnet::Eth;
 
-   my $h = Net::Libdnet::Eth->new(device => 'eth0');
+   my $h      = Net::Libdnet::Eth->new(device => 'eth0');
+   my $mac    = $h->get;
+   my $sucess = $h->add('10.0.0.1', '00:11:22:33:44:55');
+   my $sucess = $h->delete('10.0.0.1', '00:11:22:33:44:55');
+
 
 =head1 DESCRIPTION
 
@@ -80,7 +84,7 @@ Sets the hardware address specified by scalar of used network interface. Returns
 
 =item B<send> (scalar)
 
-Sends the raw data specified by scalar to the network interface. Returns the number of bytes sent on success, undef on error.
+Sends the raw data specified by scalar to the network interface. Returns the number of bytes sent on sucess, undef on error.
 
 =back
 
@@ -92,6 +96,6 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the BSD license. See LICENSE file in the source distribution archive.
 
-Copyright (c) 2008-2024, Patrice <GomoR> Auffret
+Copyright (c) 2008, Patrice <GomoR> Auffret
 
 =cut
