@@ -1,71 +1,49 @@
 #
-# $Id: Intf.pm,v c57765ed0538 2024/10/28 15:05:03 gomor $
+# $Id: Intf.pm 13 2008-11-25 21:36:12Z gomor $
 #
 package Net::Libdnet::Intf;
 use strict; use warnings;
 
-use base qw(Class::Gomor::Array);
-
-our @AS = qw(
+require Class::Gomor::Array;
+our @ISA = qw(Class::Gomor::Array);
+our @AS  = qw(
    _handle
 );
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
 use Net::Libdnet qw(:intf);
-use Net::Libdnet::Entry::Intf;
 
 sub new {
    my $self   = shift->SUPER::new(@_);
    my $handle = dnet_intf_open() or die("Intf::new: unable to open");
    $self->_handle($handle);
-   return $self;
+   $self;
 }
 
 sub get {
    my $self   = shift,
    my ($intf) = @_;
-   my $h = dnet_intf_get($self->_handle, { intf_name => $intf })
-      or return;
-   return Net::Libdnet::Entry::Intf->newFromHash($h);
+   dnet_intf_get($self->_handle, {intf_name => $intf});
 }
 
 sub getSrc {
    my $self  = shift,
    my ($src) = @_;
-   my $h = dnet_intf_get_src($self->_handle, $src)
-      or return;
-   return Net::Libdnet::Entry::Intf->newFromHash($h);
+   dnet_intf_get_src($self->_handle, $src);
 }
 
 sub getDst {
    my $self  = shift,
    my ($dst) = @_;
-   my $h = dnet_intf_get_dst($self->_handle, $dst)
-      or return;
-   return Net::Libdnet::Entry::Intf->newFromHash($h);
-}
-
-sub getSrcIntfFromDst {
-   my $self = shift;
-   my ($dst) = @_;
-   my $e = $self->getDst($dst) or return;
-   return $e->name;
-}
-
-sub getSrcIpFromDst {
-   my $self = shift;
-   my ($dst) = @_;
-   my $e = $self->getDst($dst) or return;
-   return $e->addr;
+   dnet_intf_get_dst($self->_handle, $dst);
 }
 
 sub set {
    my $self = shift;
-   my ($entry) = @_;
-   my $r = dnet_intf_set($self->_handle, $entry)
-      or return;
-   return $self;
+   my ($h)  = @_;
+   # XXX: write using only args on input, and put them into a hash
+   dnet_intf_set($self->_handle, $h);
 }
 
 sub loop {
@@ -113,14 +91,6 @@ XXX
 
 =back
 
-=over 4
-
-=item B<getSrcIntfFromDst>
-
-=item B<getSrcIpFromDst>
-
-=back
-
 =head1 AUTHOR
 
 Patrice E<lt>GomoRE<gt> Auffret
@@ -129,6 +99,6 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the BSD license. See LICENSE file in the source distribution archive.
 
-Copyright (c) 2008-2024, Patrice <GomoR> Auffret
+Copyright (c) 2008, Patrice <GomoR> Auffret
 
 =cut
