@@ -1,11 +1,11 @@
 #
-# $Id: Tun.pm,v c57765ed0538 2024/10/28 15:05:03 gomor $
+# $Id: Tun.pm 13 2008-11-25 21:36:12Z gomor $
 #
 package Net::Libdnet::Tun;
 use strict; use warnings;
 
-use base qw(Class::Gomor::Array);
-
+require Class::Gomor::Array;
+our @ISA = qw(Class::Gomor::Array);
 our @AS  = qw(
    src
    dst
@@ -101,6 +101,6 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the BSD license. See LICENSE file in the source distribution archive.
 
-Copyright (c) 2008-2024, Patrice <GomoR> Auffret
+Copyright (c) 2008, Patrice <GomoR> Auffret
 
 =cut
